LinuxProtocolRegistry class

Inheritance

Constructors

LinuxProtocolRegistry()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ProtocolScheme scheme) → Future<bool>
Used to add a scheme.
override
exists(ProtocolScheme scheme) → Future<bool>
Check if the scheme is already registered.
override
find(ProtocolScheme scheme) → Future<String?>
Used to get the application path of the scheme if its already registered.
override
findDesktopFile(String filename) → Future<File?>
Tries to resolve path from a ./desktop filename. Only checks the ~/.local/share/applications folder.
findDesktopFileWithScheme(ProtocolScheme scheme) → Future<String?>
Returns the .desktop filename that contains the scheme.scheme.
getDesktopFilePath(ProtocolScheme scheme) → String
Returns suitable path for the scheme's .desktop file.
getEntry(ProtocolScheme scheme) → String
Returns content of .desktop file with only Name and Exec.
installDesktopFile(String path, ProtocolScheme scheme) → Future<void>
Used to install a .desktop file. Recommended to pass path from getDesktopFilePath to path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(ProtocolScheme scheme) → Future<bool>
Used to remove a scheme.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited