ProtocolScheme class

Constructors

ProtocolScheme({required String scheme, String? appName, String? appPath})

Properties

appName → String?
Name of the application. Required for Linux desktop entry.
final
appPath → String?
Path of your app. Required when passing to add. Usually this is Platform.resolvedExecutable.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
URI Scheme without :// (Example: your-app)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited